@@ -46,7 +46,7 @@ EditorHandler::EditorHandler(QObject *parent)
         // if empty for bool value => false, if empty for other => default value
         // TODO: make documentation about this
         {u"=="_s, u"<mark>"_s, u"</mark>"_s, u""_s, u"background"_s, u"highlight"_s, u""_s, u""_s, u""_s, u""_s, u""_s, u""_s}, // Highlight
-        {u"-"_s, u"<sub>"_s, u"</sub>"_s, u""_s, u""_s, u""_s, u"2"_s, u"y"_s, u"y"_s, u""_s, u""_s, u""_s}, // Subscript
+        {u"--"_s, u"<sub>"_s, u"</sub>"_s, u""_s, u""_s, u""_s, u"2"_s, u"y"_s, u"y"_s, u""_s, u""_s, u""_s}, // Subscript
         {u"^"_s, u"<sup>"_s, u"</sup>"_s, u""_s, u""_s, u""_s, u"1"_s, u"y"_s, u"y"_s, u""_s, u""_s, u""_s}, // Superscript
     };
     addExtendedSyntaxs(extendedSyntaxsList);
@@ -224,7 +224,30 @@ void EditorHandler::parse(const QString &src)
 
     ++m_parseCount;
 
-    Q_EMIT askForParsing(src, m_noteDir, m_parseCount);
+    Q_EMIT askForParsing(src, m_noteDir, m_noteName, m_parseCount);
+}
+
+QString EditorHandler::getNotePath() const
+{
+    return m_noteDir + QStringLiteral("+") + m_noteName;
+}
+
+void EditorHandler::setNotePath(const QString &notePath)
+{
+    QDir note(notePath);
+    setNoteName(note.dirName());
+    note.cdUp();
+    setNoteDir(note.absolutePath());
+}
+
+QString EditorHandler::getNoteName() const
+{
+    return m_noteName;
+}
+
+void EditorHandler::setNoteName(const QString &noteName)
+{
+    m_noteName = noteName;
 }
 
 QString EditorHandler::getNoteDir() const
@@ -248,13 +271,14 @@ void EditorHandler::setNoteDir(const QString &noteDir)
     Q_EMIT renderingFinished({});
     parseDoc();
 }
+
 // !Parser
 
 // Rendering
 void EditorHandler::renderDoc()
 {
     if (m_currentMdDoc) {
-        const auto html = m_renderer->toHtml(m_currentMdDoc, m_noteDir);
+        const auto html = m_renderer->toHtml(m_currentMdDoc, QStringLiteral("&nbsp;&hookleftarrow;&nbsp;"));
 
         if (m_pluginHelper) {
             m_pluginHelper->postTokChanges();
