@@ -7,8 +7,8 @@
 #include <QQmlApplicationEngine>
 
 // Do not remove this, breaks Qt6 build
+#include <QQuickStyle>
 #include <QtQml>
-
 #include <QtWebEngineQuick>
 
 #include "app.h"
@@ -18,32 +18,21 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
-#include "logic/colorschemer.h"
-#include "logic/documentHandler.h"
-#include "logic/kleverUtility.h"
-#include "logic/qmlLinker.h"
+#ifdef WITH_BREEZEICONS_LIB
+#include <BreezeIcons>
+#endif
 
-#include "logic/editor/editorHandler.hpp"
-
-#include "logic/treeview/treeModel.h"
-
-#include "logic/printing/printingHelper.h"
-
-#include "logic/preview/styleHandler.hpp"
-
-// Plugins
-#include "logic/parser/plugins/emoji/emojiModel.h"
-#include "logic/parser/plugins/emoji/emoticonFilterModel.h"
-#include "logic/parser/plugins/noteMapper/noteMapper.h"
-#include "logic/parser/plugins/syntaxHighlight/highlightHelper.h"
-
-Q_DECL_EXPORT int main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     QtWebEngineQuick::initialize();
 
     KIconTheme::initTheme();
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
     QApplication app(argc, argv);
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
 
@@ -55,7 +44,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         // A displayable program name string.
         i18nc("@title", "KleverNotes"),
         // The program version string.
-        QStringLiteral("1.2.2"),
+        QStringLiteral("1.2.3"),
         // Short description of what the app does.
         i18n("Note taking and management application"),
         // The license this code is released under.
@@ -92,49 +81,15 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QObject::connect(config, &KleverConfig::emojiToneChanged, config, &KleverConfig::save);
     QObject::connect(config, &KleverConfig::quickEmojiDialogEnabledChanged, config, &KleverConfig::save);
 
-    qmlRegisterType<QmlLinker>("qtMdEditor", 1, 0, "QmlLinker");
-
-    qmlRegisterSingletonInstance("org.kde.Klever", 1, 0, "Config", config);
-
-    qmlRegisterSingletonType("org.kde.Klever", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+    qmlRegisterSingletonType("org.kde.klevernotes", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
         return engine->toScriptValue(KAboutData::applicationData());
     });
 
     App application;
-    qmlRegisterSingletonInstance("org.kde.Klever", 1, 0, "App", &application);
-
-    KleverUtility kleverUtility;
-    qmlRegisterSingletonInstance<KleverUtility>("org.kde.Klever", 1, 0, "KleverUtility", &kleverUtility);
-
-    DocumentHandler documentHandler;
-    qmlRegisterSingletonInstance<DocumentHandler>("org.kde.Klever", 1, 0, "DocumentHandler", &documentHandler);
-
-    MdEditor::EditorHandler editorHandler;
-    qmlRegisterSingletonInstance<MdEditor::EditorHandler>("org.kde.Klever", 1, 0, "EditorHandler", &editorHandler);
-
-    ColorSchemer colorScheme;
-    qmlRegisterSingletonInstance<ColorSchemer>("org.kde.Klever", 1, 0, "ColorSchemer", &colorScheme);
-
-    StyleHandler styleHandler;
-    qmlRegisterSingletonInstance<StyleHandler>("org.kde.Klever", 1, 0, "StyleHandler", &styleHandler);
-
-    qmlRegisterType<PrintingUtility>("org.kde.Klever", 1, 0, "PrintingUtility");
-
-    qmlRegisterType<NoteTreeModel>("org.kde.Klever", 1, 0, "NoteTreeModel");
-
-    // === PLUGINS ===
-    qmlRegisterType<EmoticonFilterModel>("neochatComponents", 1, 0, "EmoticonFilterModel");
-    qmlRegisterSingletonInstance("neochatComponents", 1, 0, "EmojiModel", &EmojiModel::instance());
-
-    NoteMapper noteMapper;
-    qmlRegisterSingletonInstance<NoteMapper>("org.kde.Klever", 1, 0, "NoteMapper", &noteMapper);
-
-    HighlightHelper highlightHelper;
-    qmlRegisterSingletonInstance<HighlightHelper>("org.kde.Klever", 1, 0, "HighlightHelper", &highlightHelper);
-    // === === === ===
+    qmlRegisterSingletonInstance("org.kde.klevernotes", 1, 0, "App", &application);
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:/contents/ui/main.qml")));
+    engine.loadFromModule("org.kde.klevernotes", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
